@@ -1,4 +1,5 @@
 from typing import Optional, Union, Any
+from datetime import datetime
 
 import aiohttp
 
@@ -46,6 +47,13 @@ class FeedsConnector(AnyRunConnector):
             enable_requests
         )
 
+        self._taxii_delta_timestamp: datetime = datetime(year=1970, month=1, day=1)
+
+    @property
+    def taxii_delta_timestamp(self) -> Optional[str]:
+        if self._taxii_delta_timestamp:
+            return self._taxii_delta_timestamp.strftime(Config.TAXII_DATE_FORMAT)
+
     def check_authorization(self) -> dict:
         """
         Makes a request to check the validity of the API key.
@@ -69,14 +77,15 @@ class FeedsConnector(AnyRunConnector):
     def get_taxii_stix(
             self,
             collection: str = 'full',
-            match_type: Optional[str] = None,
+            match_type: str = 'indicator',
             match_id: Optional[str] = None,
             match_revoked: bool = False,
-            match_version: str = 'last',
-            get_new_ioc: bool = False,
+            match_version: str = 'all',
             added_after: Optional[str] = None,
-            limit: int = 100,
-            next_page: Optional[str] = None
+            modified_after: Optional[str] = None,
+            limit: int = 10000,
+            next_page: Optional[str] = None,
+            get_delta: bool = False
     ) -> dict:
         """
         Returns a list of ANY.RUN Feeds TAXII stix objects according to the specified query parameters
@@ -86,10 +95,11 @@ class FeedsConnector(AnyRunConnector):
         :param match_id: IOC identifier.
         :param match_revoked: Enable or disable receiving revoked feeds in report.
         :param match_version: Filter STIX objects by their object version.
-        :param get_new_ioc: Receive only updated IOCs since the last request.
         :param added_after: Receive IOCs after specified date.
+        :param modified_after: Receive IOCs after specified date. Example: 2025-04-15.
         :param limit: Number of tasks on a page. Default, all IOCs are included.
         :param next_page: Page identifier.
+        :param get_delta: Get only indicators modified since the last request. Works starting from the second request
         :return: The list of feeds in **stix** format
         """
         return execute_synchronously(
@@ -99,23 +109,25 @@ class FeedsConnector(AnyRunConnector):
             match_id,
             match_revoked,
             match_version,
-            get_new_ioc,
             added_after,
+            modified_after,
             limit,
-            next_page
+            next_page,
+            get_delta
         )
 
     async def get_taxii_stix_async(
             self,
             collection: str = 'full',
-            match_type: Optional[str] = None,
+            match_type: str = 'indicator',
             match_id: Optional[str] = None,
-            match_version: str = 'last',
             match_revoked: bool = False,
+            match_version: str = 'all',
             added_after: Optional[str] = None,
             modified_after: Optional[str] = None,
-            limit: int = 100,
-            next_page: Optional[str] = None
+            limit: int = 10000,
+            next_page: Optional[str] = None,
+            get_delta: bool = False
     ) -> dict:
         """
         Returns a list of ANY.RUN Feeds TAXII stix objects according to the specified query parameters
@@ -127,12 +139,17 @@ class FeedsConnector(AnyRunConnector):
         :param match_version: Filter STIX objects by their object version.
         :param match_revoked: Enable or disable receiving revoked feeds in report.
         :param added_after: Receive IOCs after specified date. Example: 2025-04-15.
-        :param modified_after:
+        :param modified_after: Receive IOCs after specified date. Example: 2025-04-15.
         :param limit: Number of tasks on a page. Default, all IOCs are included.
         :param next_page: Page identifier.
+        :param get_delta: Get only indicators modified since the last request. Works starting from the second request
         :return: The list of feeds in **stix** format
         """
         collection_id = await self._get_collection_id(collection)
+
+        if get_delta and self.taxii_delta_timestamp:
+            modified_after = self.taxii_delta_timestamp
+
         url = await self._generate_feeds_url(
             f'{Config.ANY_RUN_API_URL}/feeds/taxii2/api1/collections/{collection_id}/objects/?',
             {
@@ -147,7 +164,10 @@ class FeedsConnector(AnyRunConnector):
                 'next': next_page
              }
         )
+
         response_data = await self._make_request_async('GET', url)
+        await self._update_taxii_delta_timestamp()
+
         return response_data
 
     def get_stix(
@@ -450,6 +470,16 @@ class FeedsConnector(AnyRunConnector):
         )
         return url + query_params
 
+    async def _update_taxii_delta_timestamp(self) -> None:
+        """ Updates taxii delta timestamp """
+        delta_timestamp = self._response_headers.get('X-TAXII-Date-Modified-Last')
+
+        if delta_timestamp:
+            delta_timestamp = datetime.strptime(delta_timestamp, Config.TAXII_DATE_FORMAT)
+
+            if (not self._taxii_delta_timestamp) or self._taxii_delta_timestamp < delta_timestamp:
+                self._taxii_delta_timestamp = delta_timestamp
+
     @staticmethod
     async def _parse_boolean(param: Any) -> Union[str, Any]:
         """ Converts a boolean value to a lowercase string """
